SynOpCounter
============

.. currentmodule:: sinabs.synopcounter

SNNSynOpCounter
~~~~~~~~~~~~~~~

.. autoclass:: SNNSynOpCounter
    :members:


SynOpCounter
~~~~~~~~~~~~

.. autoclass:: SynOpCounter
    :members:
